==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/fr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Vie privée",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Le centre de confidentialité indique où sont stockées vos données et qui peut y accéder soit parce que vous partager ces données explicitement soit parce que des administrateurs ont accès à ces données.",
    "Remove external admin" : "Supprimer l'administrateur externe",
    "Add external admin" : "Ajouter un administrateur externe",
    "Your files are not protected by encryption." : "Vos fichiers ne sont pas protégés par chiffrement.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Vos fichiers sont chiffrés avec {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Les disques de ce serveur sont protégés par chiffrement.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Vos fichiers sont chiffrés avec {linkopen}server-side-encryption ↗{linkclose}. De plus, ce serveur est protégé avec full-disk-encryption.",
    "This server is using full-disk-encryption." : "Les disques de ce serveur sont chiffrés.",
    "Change data location" : "Modifier l'emplacement des données",
    "Your data is located in: " : "Vos données sont situées en :",
    "The admin hasn't selected the location of the server yet." : "L'administrateur n'a pas encore indiqué l'emplacement du serveur.",
    "Please select a country" : "Veuillez sélectionner un pays",
    "You don't have any shares with individual users." : "Vous n'avez aucun partage avec des utilisateurs individuels.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Émirats Arabes Unis",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanie",
    "Armenia" : "Arménie",
    "Angola" : "Angola",
    "Argentina" : "Argentine",
    "Austria" : "Autriche",
    "Australia" : "Australie",
    "Azerbaijan" : "Azerbaïdjan",
    "Bosnia and Herzegowina" : "Bosnie-Herzégovine",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgique",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarie",
    "Burundi" : "Burundi",
    "Benin" : "Bénin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivie",
    "Brazil" : "Brésil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoutan",
    "Botswana" : "Botswana",
    "Belarus" : "Biélorussie",
    "Belize" : "Bélize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "République Démocratique du Congo",
    "Central African Republic" : "République centrafricaine",
    "Congo" : "Congo",
    "Switzerland" : "Suisse",
    "Cote d'Ivoire" : "Côte d'Ivoire",
    "Chile" : "Chili",
    "Cameroon" : "Cameroun",
    "China" : "Chine",
    "Colombia" : "Colombie",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chypre",
    "Czech" : "Tchèque",
    "Germany" : "Allemagne",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danemark",
    "Dominican Republic" : "République Dominicaine",
    "Algeria" : "Algérie",
    "Ecuador" : "Équateur",
    "Estonia" : "Estonie",
    "Egypt" : "Égypte",
    "West Sahara" : "Sahara occidental",
    "Eritrea" : "Érythrée",
    "Spain" : "Espagne",
    "Ethiopia" : "Éthiopie",
    "Finland" : "Finlande",
    "Fiji" : "Fidji",
    "Falkland Islands" : "Îles Falkland",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "Royaume Uni",
    "Georgia" : "Géorgie",
    "Ghana" : "Ghana",
    "Greenland" : "Groenland",
    "Gambia" : "Gambie",
    "Guinea" : "Guinée",
    "Equatorial Guinea" : "Guinée Équatoriale",
    "Greece" : "Grèce",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinée-Bissau",
    "Guyana" : "Guyane",
    "Honduras" : "Honduras",
    "Croatia" : "Croatie",
    "Haiti" : "Haïti",
    "Hungary" : "Hongrie",
    "Indonesia" : "Indonésie",
    "Ireland" : "Irlande",
    "Israel" : "Israël",
    "India" : "Inde",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islande",
    "Italy" : "Italie",
    "Jamaica" : "Jamaïque",
    "Jordan" : "Jordanie",
    "Japan" : "Japon",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambodge",
    "North Korea" : "Corée du Nord",
    "South Korea" : "Corée du Sud",
    "Kuwait" : "Koweït",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituanie",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Lettonie",
    "Libya" : "Libye",
    "Morocco" : "Maroc",
    "Moldova" : "Moldavie",
    "Montenegro" : "Monténégro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macédoine",
    "Mali" : "Mali",
    "Myanmar" : "Birmanie",
    "Mongolia" : "Mongolie",
    "Mauritania" : "Mauritanie",
    "Malawi" : "Malawi",
    "Mexico" : "Mexique",
    "Malaysia" : "Malaisie",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibie",
    "New Caledonia" : "Nouvelle-Calédonie",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Pays-Bas",
    "Norway" : "Norvège",
    "Nepal" : "Népal",
    "New Zealand" : "Nouvelle-Zélande",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Pérou",
    "Papua New Guinea" : "Papouasie-Nouvelle-Guinée",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Pologne",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Roumanie",
    "Serbia" : "Serbie",
    "Russia" : "Russie",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabie Saoudite",
    "Solomon Islands" : "Îles Salomon",
    "Sudan" : "Soudan",
    "Sweden" : "Suède",
    "Singapore" : "Singapour",
    "Slovenia" : "Slovénie",
    "Slovakia" : "Slovaquie",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Sénégal",
    "Somalia" : "Somalie",
    "Suriname" : "Suriname",
    "South Sudan" : "Soudan du Sud",
    "El Salvador" : "Salvador",
    "Syria" : "Syrie",
    "Swaziland" : "Swaziland",
    "Chad" : "Tchad",
    "Fr. S. Antarctic Lands" : "Terres australes et antarctiques françaises",
    "Togo" : "Togo",
    "Thailand" : "Thaïlande",
    "Tajikistan" : "Tadjikistan",
    "Timor-Leste" : "Timor oriental",
    "Turkmenistan" : "Turkménistan",
    "Tunisia" : "Tunisie",
    "Turkey" : "Turquie",
    "Trinidad and Tobago" : "Trinidad et Tobago",
    "Taiwan" : "Taïwan",
    "Tanzania" : "Tanzanie",
    "Ukraine" : "Ukraine",
    "Uganda" : "Ouganda",
    "United States" : "États-Unis d'Amérique",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Ouzbékistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Viêtnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yémen",
    "South Africa" : "Afrique du Sud",
    "Zambia" : "Zambie",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Votre compte Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vos données représentent qui vous êtes et peuvent facilement être exploitées. Chez Nextcloud, nous pensons que vous avez le droit de décider de l’utilisation de vos données. Nextcloud protège vos droits tels que définis dans le Manifeste des données utilisateur !",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Définir les droits fondamentaux des personnes pour contrôler leurs propres données à l’ère d’Internet",
    "Control" : "Contrôler",
    "over user data access" : "des accès aux données utilisateurs",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les données transmises explicitement et volontairement par un utilisateur doivent être sous le contrôle ultime de l’utilisateur. Les utilisateurs devraient pouvoir décider à qui accorder l’accès direct à leurs données et avec quelles autorisations et licences cet accès devrait être accordé.",
    "Knowledge" : "Savoir",
    "of how the data is stored" : "comment les données sont stockées",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Lorsque les données sont téléversées vers un fournisseur de services spécifique, les utilisateurs doivent être informés de l’endroit où ce fournisseur de services particulier stocke les données, de la durée, de la juridiction dans laquelle le fournisseur de services spécifique opère et des lois qui s’appliquent.",
    "Freedom" : "Liberté",
    "to choose a platform" : "de choisir une plate-forme",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Les utilisateurs doivent toujours pouvoir extraire leurs données du service à tout moment sans rencontrer de blocage de la part du vendeur. Des standards ouverts pour les formats et les protocoles sont nécessaires pour garantir cela.",
    "Learn more ↗" : " En savoir plus↗",
    "Where is your data?" : "Où sont vos données ?",
    "Who has access to your data?" : "Qui a accès à vos données ?",
    "Administrators" : "Administrateurs",
    "People you shared with" : "Personnes avec qui vous avez partagé",
    "Privacy policy" : "Politique de confidentialité",
    "Read the privacy policy." : "Lisez la politique de confidentialité.",
    "Encryption" : "Chiffrement"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-19.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/fr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Vie privée",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Le centre de confidentialité indique où sont stockées vos données et qui peut y accéder soit parce que vous partager ces données explicitement soit parce que des administrateurs ont accès à ces données.",
    "Remove external admin" : "Supprimer l'administrateur externe",
    "Add external admin" : "Ajouter un administrateur externe",
    "Name of external admin" : "Nom de l'administrateur externe",
    "This server is using full-disk-encryption." : "Les disques de ce serveur sont chiffrés.",
    "Your files are not protected by encryption." : "Vos fichiers ne sont pas protégés par chiffrement.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Vos fichiers sont chiffrés avec {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Les disques de ce serveur sont protégés par chiffrement.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Vos fichiers sont chiffrés avec {linkopen}server-side-encryption ↗{linkclose}. De plus, ce serveur est protégé avec full-disk-encryption.",
    "Your data is located in: " : "Vos données sont situées en :",
    "The admin hasn't selected the location of the server yet." : "L'administrateur n'a pas encore indiqué l'emplacement du serveur.",
    "Change data location" : "Modifier l'emplacement des données",
    "Please select a region" : "Veuillez sélectionner un Pays",
    "You don't have any shares with individual users." : "Vous n'avez aucun partage avec des utilisateurs individuels.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorre",
    "United Arab Emirates" : "Émirats Arabes Unis",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua et Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanie",
    "Armenia" : "Arménie",
    "Angola" : "Angola",
    "Antarctica" : "Antarctique",
    "Argentina" : "Argentine",
    "American Samoa" : "Samoa américaines",
    "Austria" : "Autriche",
    "Australia" : "Australie",
    "Aruba" : "Aruba",
    "Åland Islands" : "Îles Åland",
    "Azerbaijan" : "Azerbaïdjan",
    "Bosnia and Herzegovina" : "Bosnie-Herzégovine",
    "Barbados" : " La Barbade",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgique",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarie",
    "Bahrain" : "Bahreïn",
    "Burundi" : "Burundi",
    "Benin" : "Bénin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : " Les Bermudes",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivie",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Saint-Eustache et Saba",
    "Brazil" : "Brésil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoutan",
    "Bouvet Island" : "Île Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Biélorussie",
    "Belize" : "Bélize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Îles Cocos (Keeling)",
    "Democratic Republic of the Congo" : "République Démocratique du Congo",
    "Central African Republic" : "République centrafricaine",
    "Congo" : "Congo",
    "Switzerland" : "Suisse",
    "Cote d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Îles Cook",
    "Chile" : "Chili",
    "Cameroon" : "Cameroun",
    "China" : "Chine",
    "Colombia" : "Colombie",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cap-Vert",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Île Christmas",
    "Cyprus" : "Chypre",
    "Czech" : "Tchèque",
    "Germany" : "Allemagne",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danemark",
    "Dominican Republic" : "République Dominicaine",
    "Algeria" : "Algérie",
    "Ecuador" : "Équateur",
    "Estonia" : "Estonie",
    "Egypt" : "Égypte",
    "West Sahara" : "Sahara occidental",
    "Eritrea" : "Érythrée",
    "Spain" : "Espagne",
    "Ethiopia" : "Éthiopie",
    "Finland" : "Finlande",
    "Fiji" : "Fidji",
    "Falkland Islands" : "Îles Falkland",
    "Micronesia" : "Micronésie",
    "Faroe Islands" : "Îles Féroé",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "Royaume Uni",
    "Grenada" : "Grenade",
    "Georgia" : "Géorgie",
    "French Guiana" : "Guyane française",
    "Guernsey" : "Guernesey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambie",
    "Guinea" : "Guinée",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinée Équatoriale",
    "Greece" : "Grèce",
    "South Georgia and the South Sandwich Islands" : "Géorgie du Sud et les îles Sandwich du Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinée-Bissau",
    "Guyana" : "Guyane",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Îles Heard et MacDonald",
    "Croatia" : "Croatie",
    "Haiti" : "Haïti",
    "Hungary" : "Hongrie",
    "Indonesia" : "Indonésie",
    "Ireland" : "Irlande",
    "Israel" : "Israël",
    "Isle of Man" : "Île de Man",
    "India" : "Inde",
    "British Indian Ocean Territory" : "Territoire britannique de l'océan Indien",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islande",
    "Italy" : "Italie",
    "Jamaica" : "Jamaïque",
    "Jordan" : "Jordanie",
    "Japan" : "Japon",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambodge",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Christophe et Niévès",
    "North Korea" : "Corée du Nord",
    "South Korea" : "Corée du Sud",
    "Kuwait" : "Koweït",
    "Cayman Islands" : "Îles Caïmans",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Saint Lucia" : "Sainte Lucie",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituanie",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Lettonie",
    "Libya" : "Libye",
    "Morocco" : "Maroc",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavie",
    "Montenegro" : "Monténégro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Îles Marshall",
    "Macedonia" : "Macédoine",
    "Mali" : "Mali",
    "Myanmar" : "Birmanie",
    "Mongolia" : "Mongolie",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Îles Mariannes du Nord",
    "Mauritania" : "Mauritanie",
    "Montserrat" : "Montserrat",
    "Malta" : "Malte",
    "Mauritius" : "Île Maurice",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexique",
    "Malaysia" : "Malaisie",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibie",
    "New Caledonia" : "Nouvelle-Calédonie",
    "Niger" : "Niger",
    "Norfolk Island" : "Île Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Pays-Bas",
    "Norway" : "Norvège",
    "Nepal" : "Népal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nouvelle-Zélande",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Pérou",
    "French Polynesia" : "Polynésie française",
    "Papua New Guinea" : "Papouasie-Nouvelle-Guinée",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Pologne",
    "Saint Pierre and Miquelon" : "Saint Pierre et Miquelon",
    "Pitcairn" : "Île Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestine",
    "Portugal" : "Portugal",
    "Palau" : "Palaos",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Roumanie",
    "Serbia" : "Serbie",
    "Russia" : "Russie",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabie Saoudite",
    "Solomon Islands" : "Îles Salomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Soudan",
    "Sweden" : "Suède",
    "Singapore" : "Singapour",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sainte-Hélène, Ascension et Tristan da Cunha",
    "Slovenia" : "Slovénie",
    "Svalbard and Jan Mayen" : "Svalbard et Jan Mayen",
    "Slovakia" : "Slovaquie",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Saint Marin",
    "Senegal" : "Sénégal",
    "Somalia" : "Somalie",
    "Suriname" : "Suriname",
    "South Sudan" : "Soudan du Sud",
    "Sao Tome and Principe" : "Sao Tomé et Principe",
    "El Salvador" : "Salvador",
    "Sint Maarten" : "Saint Martin",
    "Syria" : "Syrie",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Îles Turques et Caïques",
    "Chad" : "Tchad",
    "Fr. S. Antarctic Lands" : "Terres australes et antarctiques françaises",
    "Togo" : "Togo",
    "Thailand" : "Thaïlande",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor oriental",
    "Turkmenistan" : "Turkménistan",
    "Tunisia" : "Tunisie",
    "Tonga" : "Tonga",
    "Turkey" : "Turquie",
    "Trinidad and Tobago" : "Trinidad et Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taïwan",
    "Tanzania" : "Tanzanie",
    "Ukraine" : "Ukraine",
    "Uganda" : "Ouganda",
    "United States Minor Outlying Islands" : "Îles mineures éloignées des États-Unis",
    "United States" : "États-Unis d'Amérique",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Ouzbékistan",
    "Holy See" : "Vatican",
    "Saint Vincent and the Grenadines" : "Saint Vincent et les Grenadines",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Îles Vierges Britanniques",
    "Virgin Islands (U.S.)" : "Îles Vierges des États-Unis",
    "Vietnam" : "Viêtnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis et Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yémen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrique du Sud",
    "Zambia" : "Zambie",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Votre compte Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vos données représentent qui vous êtes et peuvent facilement être exploitées. Chez Nextcloud, nous pensons que vous avez le droit de décider de l’utilisation de vos données. Nextcloud protège vos droits tels que définis dans le Manifeste des données utilisateur !",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Définir les droits fondamentaux des personnes pour contrôler leurs propres données à l’ère d’Internet",
    "Control" : "Contrôler",
    "over user data access" : "des accès aux données utilisateurs",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les données transmises explicitement et volontairement par un utilisateur doivent être sous le contrôle ultime de l’utilisateur. Les utilisateurs devraient pouvoir décider à qui accorder l’accès direct à leurs données et avec quelles autorisations et licences cet accès devrait être accordé.",
    "Knowledge" : "Savoir",
    "of how the data is stored" : "comment les données sont stockées",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Lorsque les données sont téléversées vers un fournisseur de services spécifique, les utilisateurs doivent être informés de l’endroit où ce fournisseur de services particulier stocke les données, de la durée, de la juridiction dans laquelle le fournisseur de services spécifique opère et des lois qui s’appliquent.",
    "Freedom" : "Liberté",
    "to choose a platform" : "de choisir une plate-forme",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Les utilisateurs doivent toujours pouvoir extraire leurs données du service à tout moment sans rencontrer de blocage de la part du vendeur. Des standards ouverts pour les formats et les protocoles sont nécessaires pour garantir cela.",
    "Learn more ↗" : " En savoir plus↗",
    "Where is your data?" : "Où sont vos données ?",
    "Who has access to your data?" : "Qui a accès à vos données ?",
    "Administrators" : "Administrateurs",
    "People you shared with" : "Personnes avec qui vous avez partagé",
    "Privacy policy" : "Politique de confidentialité",
    "Read the privacy policy." : "Lisez la politique de confidentialité.",
    "Encryption" : "Chiffrement",
    "Please select a country" : "Veuillez sélectionner un pays",
    "Bosnia and Herzegowina" : "Bosnie-Herzégovine"
},
"nplurals=2; plural=(n > 1);");
